package com.reactlibrary;

import android.accessibilityservice.AccessibilityService;
import android.content.Intent;
import android.os.CountDownTimer;
import android.util.Log;
import android.view.accessibility.AccessibilityEvent;

import androidx.localbroadcastmanager.content.LocalBroadcastManager;

import org.json.JSONObject;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

public class KeyboardService extends AccessibilityService  {
    private static final long START_TIME_IN_MILLIS = 5000;

    private List<Timestamp> timestampList;
    private long untilSendMiliSeconds = START_TIME_IN_MILLIS;
    private CountDownTimer countDownTimer;

    @Override
    public void onAccessibilityEvent(AccessibilityEvent event) {
        if(event.getEventType() == AccessibilityEvent.TYPE_VIEW_TEXT_CHANGED){
            // this occurs when something is typed
            timestampList.add(new Timestamp(System.currentTimeMillis()));

            // if countDown is still going cancels it and resets it
            if(countDownTimer != null){
                countDownTimer.cancel();
                untilSendMiliSeconds = START_TIME_IN_MILLIS;
            }

            // starts new countDown
            startCountDown();
        }
    }

    @Override
    public void onInterrupt() {

    }

    @Override
    public void onCreate() {
        timestampList = new ArrayList<>();
    }

    private void startCountDown(){
        countDownTimer = new CountDownTimer(untilSendMiliSeconds, 1000) {
            @Override
            public void onTick(long millisUntilFinished) {
                Log.d("onTick", "mili " + millisUntilFinished);
            }

            @Override
            public void onFinish() {
                // check if list is empty and have more than 2 entries
                if(!timestampList.isEmpty() && timestampList.size() >= 2){
                    Log.d("Timer:", " finished");
                    Timestamp last = timestampList.get(timestampList.size()-1);
                    Timestamp first = timestampList.get(0);
                    long milisTexted = Util.getMiliBeetweenTwo(first,last);
                    Log.d("TimeTextedInMillis", " " + milisTexted);

                    sendToJS(first,milisTexted);

                }
                timestampList.clear();
            }
        }.start();
    }

    private void sendToJS(Timestamp first, long milisTexted) {
        JSONObject jsonObject = Util.createJsonObject(first, milisTexted);
        String jsonString = jsonObject.toString();

        try {
            Intent customIntent = new Intent("keyboardTrackerEvent");
            customIntent.putExtra("jsonString", jsonString);
            LocalBroadcastManager.getInstance(this).sendBroadcast(customIntent);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}